;;; emacs-cs-utils-init.el --- initialization of czech support

;; Copyright (C) 1997, 1998, 1999, 2000, 2001 Free Software Foundation, Inc.

;; Author:     Pavel Jank <Pavel@Janik.cz>
;; Version:    21.1
;; Keywords:   czech

;; This file is NOT part of GNU Emacs.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Commentary:

;; This file can be used to initialize the czech support in GNU Emacs
;; 21. Just add:
;;
;;    (load "emacs-cs-utils-init")
;;
;; to your ~/.emacs and everything will work :-) If it doesn't, read the
;; documentation...

;;; Code:

;;
;; Define the menu
;;

(defvar menu-bar-czech-menu (make-sparse-keymap))

(define-key menu-bar-czech-menu [customize-emacs-cs-utils]
  '(menu-item "Customize Emacs-cs-utils"
	      (lambda()
		(interactive)
		(customize-group 'emacs-cs-utils))
	      :help "Customize the settings of Emacs-cs-utils"))

(define-key menu-bar-czech-menu [customize-default-input-method]
  '(menu-item "Customize Default Input Method"
	      (lambda()
		(interactive)
		(customize-variable 'default-input-method))
	      :help "Customize the default input method"))

(define-key menu-bar-czech-menu [separator-czech-2]
  '("--"))

(define-key menu-bar-czech-menu [tildify-buffer]
  '(menu-item "Tildify Buffer" tildify-buffer
	     :help "Fill in missing non-breakable spaces in buffer"))

(define-key menu-bar-czech-menu [tildify-region]
  '(menu-item "Tildify Region" tildify-region
	     :help "Fill in missing non-breakable spaces in region"))

(define-key menu-bar-czech-menu [separator-czech-1]
  '("--"))

(define-key menu-bar-czech-menu [toggle-input-method]
  '(menu-item "Toggle Input Method" toggle-input-method
	      :help "Switch between various keyboards"))

;;
;; Customize stuff
;;

(defgroup emacs-cs-utils nil
  "Czech support utilities for GNU Emacs."
  :group 'emacs)

(defcustom emacs-cs-utils-menu t
  "*If non-nil, show the emacs-cs-utils menu in the Tools menu."
  :type 'boolean
  :set (lambda (symbol value)
	 (if value
	     (define-key menu-bar-tools-menu [czech]
	       (cons "Emacs-cs-utils" menu-bar-czech-menu))
	   (define-key menu-bar-tools-menu [czech] nil))
	 (custom-set-default symbol value))
  :group 'emacs-cs-utils)

(defcustom emacs-cs-utils-1250 t
  "*If non-nil, define CP1250 codepage."
  :type 'boolean
  :set (lambda (symbol value)
	 (if value
	     (codepage-setup '1250))
	 (custom-set-default symbol value))
  :group 'emacs-cs-utils)

(defcustom emacs-cs-utils-852 t
  "*If non-nil, define CP852 codepage."
  :type 'boolean
  :set (lambda (symbol value)
	 (if value
	     (codepage-setup '852))
	 (custom-set-default symbol value))
  :group 'emacs-cs-utils)


(defcustom emacs-cs-utils-french-nobreak t
  "*If non-nil, do not break after one-letter words."
  :type 'boolean
  :set (lambda (symbol value)
	 (if value
	     (setq fill-nobreak-predicate 'fill-french-nobreak-p)
	   (setq fill-nobreak-predicate nil))
	 (custom-set-default symbol value))
  :group 'emacs-cs-utils)

(defcustom emacs-cs-utils-default-dictionary t
  "*If non-nil, set the default ispell dictionary to czech/slovak."
  :type 'boolean
  :set (lambda (symbol value)
	 (if value
	     (cond
	      ((equal current-language-environment "Czech")
	       (ispell-change-dictionary "czech" t))
	      ((equal current-language-environment "Slovak")
	       (ispell-change-dictionary "slovak" t)))
	   (ispell-change-dictionary nil t))
	 (custom-set-default symbol value))
  :group 'emacs-cs-utils)

(defcustom emacs-cs-utils-calendar-names t
  "*If non-nil, use names in national calendar."
  :type 'boolean
  :group 'emacs-cs-utils)

(defcustom emacs-cs-utils-calendar t
  "*If non-nil, use national calendar."
  :type 'boolean
  :set (lambda (symbol value)
	 (if value
	     (cond
	      ((equal current-language-environment "Czech")
	       (require 'czech-calendar))
	      ((equal current-language-environment "Slovak")
	       (require 'slovak-calendar))))
	 (custom-set-default symbol value))
  :group 'emacs-cs-utils)

(defcustom emacs-cs-utils-scratch t
  "*If non-nil, redefine the initial message for scratch buffer."
  :type 'boolean
  :set (lambda (symbol value)
	 (if value
	     (cond
	      ((equal current-language-environment "Czech")
	       (setq initial-scratch-message ";; Tento buffer je uren pro poznmky, kter nechcete uloit
;; a pro vyhodnocovn vraz v Lispu. Pokud chcete vytvoit soubor, otevete
;; ho pomoc C-x C-f a potom mete vytvoit nov text v novm bufferu.

"))
	      ((equal current-language-environment "Slovak")
	       (setq initial-scratch-message ";; Tento buffer je uren pre poznmky, ktor nechcete uloi
;; a pre vyhodnocovanie Lispovch vrazov. Ak chcete vytvori sbor, otvorte
;; ho pomocou C-x C-f a potom mete vytvori nov text v novom bufferi.

"))))
	 (custom-set-default symbol value))
  :group 'emacs-cs-utils)

;;
;; Default input method
;;

; (setq default-input-method "czech")
; (setq default-input-method "czech-qwerty")
; (setq default-input-method "czech-prog-1")
; (setq default-input-method "czech-prog-2")
; (setq default-input-method "czech-prog-3")

;;
;; Pause switches between input methods
;;

(global-set-key [pause] 'toggle-input-method)
(define-key isearch-mode-map [pause] 'isearch-toggle-input-method)

;;
;; French breaking
;;

;; This code is from Stefan Monnier
(defun fill-french-nobreak-p ()
  (or (looking-at "[ \t]*[])}?!;:-]")
      (save-excursion
	(skip-chars-backward " \t")
	(unless (bolp)
	  (backward-char 1))
	(or (looking-at "[([{]")
	    ;; Don't cut right after a single-letter word.
	    (and (memq (preceding-char) '(?\t ?\ ))
		 (eq (char-syntax (following-char)) ?w))))))

;;; emacs-cs-utils-init.el ends here
